/**
 * @public
 */
export class ToastBuilder {
    /**
     * Add position to toast
     * @public
     * @param position - {@link ToastPosition}
     * @returns
     */
    withPosition(position) {
        this.position = position;
        return this;
    }
    /**
     * Add auto close to notification
     * @public
     * @param autoClose - boolean
     * @returns
     */
    withAutoClose(autoClose) {
        this.autoClose = autoClose;
        return this;
    }
    /**
     * Add close timeout to notification
     * @public
     * @param closeTimeout - number
     * @returns
     */
    withCloseTimeout(closeTimeout) {
        this.closeTimeout = closeTimeout;
        return this;
    }
    /**
     * Add type to notification, if the type is anything other than 'warning' or 'success' do not add it
     * @public
     * @param type - {@link NotificationType}
     * @returns
     */
    withType(type) {
        this.type = type;
        return this;
    }
    /**
     * Add details data to notifications
     * @public
     * @param details - NotificationDataRow
     * @returns
     */
    withDetails(details) {
        this.details = details;
        return this;
    }
    /**
     * Add buttons to notifications
     * @public
     * @param buttons - ToastButton[]
     * @returns
     */
    withButtons(buttons) {
        this.buttons = buttons;
        return this;
    }
    /**
     * Build notification
     * @returns Toast
     */
    build() {
        let toast = {};
        if (this.position) {
            toast = { position: this.position, ...toast };
        }
        if (this.autoClose) {
            toast = { autoClose: this.autoClose, ...toast };
        }
        if (this.closeTimeout) {
            toast = { closeTimeout: this.closeTimeout, ...toast };
        }
        if (this.type) {
            toast = { type: this.type, ...toast };
        }
        if (this.details) {
            toast = { details: this.details, ...toast };
        }
        if (this.buttons) {
            toast = { buttons: this.buttons, ...toast };
        }
        return toast;
    }
}
/**
 * Get notification builder instance
 * @public
 */
export const getToastBuilder = () => new ToastBuilder();
