import { getNotificationContainer } from '../notification-util';
/**
 * Shows the notificationStructure
 * @internal
 * @param notificationStructure - The NotificationStructure object
 * @param tagName - The tag name to create prefix for the design system provider & notificationStructure component
 * @returns
 * */
export const showToast = (notificationStructure, tagName) => {
    const tagPrefix = tagName.split('-')[0];
    const container = getNotificationContainer('notify-container', tagName);
    if (container) {
        container.style.position = 'fixed';
        switch (notificationStructure?.config?.toast?.position) {
            case 'top-left':
                container.style.top = '0';
                container.style.left = '0';
                break;
            case 'bottom-left':
                container.style.bottom = '0';
                container.style.left = '0';
                break;
            case 'bottom-right':
                container.style.bottom = '0';
                container.style.right = '0';
                break;
            default:
                container.style.top = '0';
                container.style.right = '0';
        }
    }
    const toastNotify = document.createElement(`${tagPrefix}-toast`);
    const toastTitle = document.createElement('div');
    toastTitle.setAttribute('slot', 'top');
    toastTitle.textContent = notificationStructure.title;
    const toastDetails = document.createElement('div');
    toastDetails.setAttribute('slot', 'content');
    toastDetails.textContent = notificationStructure?.body || '';
    const toastDate = document.createElement('div');
    toastDate.setAttribute('slot', 'date');
    toastDate.textContent = notificationStructure?.createdAt?.toLocaleTimeString() || '';
    let toastBottom;
    if (notificationStructure?.config?.toast?.buttons &&
        notificationStructure?.config?.toast?.buttons?.length) {
        toastBottom = document.createElement('div');
        toastBottom.setAttribute('slot', 'bottom');
        notificationStructure.config.toast.buttons.forEach((button) => {
            const buttonElement = document.createElement(`${tagPrefix}-button`);
            buttonElement.textContent = button.placeholder || 'example placeholder';
            buttonElement.addEventListener('click', () => {
                const { details } = notificationStructure.config.toast;
                if (button.action) {
                    return button.action({
                        details,
                        buttonElement,
                        toastElement: toastNotify,
                    });
                }
            });
            if (button.appearance) {
                buttonElement.setAttribute('appearance', button.appearance);
            }
            toastBottom.appendChild(buttonElement);
        });
    }
    toastNotify.setAttribute('notify', notificationStructure?.config?.toast?.type || '');
    notificationStructure?.config?.toast?.autoClose
        ? toastNotify.setAttribute('auto-close', `${notificationStructure?.config?.toast?.autoClose}`)
        : '';
    notificationStructure?.config?.toast?.closeTimeout
        ? toastNotify.setAttribute('close-timeout', `${notificationStructure?.config?.toast?.closeTimeout}`)
        : '';
    toastNotify.appendChild(toastTitle);
    toastNotify.appendChild(toastDetails);
    toastNotify.appendChild(toastDate);
    if (toastBottom) {
        toastNotify.appendChild(toastBottom);
    }
    container.appendChild(toastNotify);
};
